( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/glib-sharp/2.6.0.0__35e10195dab3c99f/glib-sharp.dll glib-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/pango-sharp/2.6.0.0__35e10195dab3c99f/pango-sharp.dll pango-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/atk-sharp/2.6.0.0__35e10195dab3c99f/atk-sharp.dll atk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gdk-sharp/2.6.0.0__35e10195dab3c99f/gdk-sharp.dll gdk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtk-sharp/2.6.0.0__35e10195dab3c99f/gtk-sharp.dll gtk-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/glade-sharp/2.6.0.0__35e10195dab3c99f/glade-sharp.dll glade-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/art-sharp/2.6.0.0__35e10195dab3c99f/art-sharp.dll art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gnome-vfs-sharp/2.6.0.0__35e10195dab3c99f/gnome-vfs-sharp.dll gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gnome-sharp/2.6.0.0__35e10195dab3c99f/gnome-sharp.dll gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtkhtml-sharp/2.6.0.0__35e10195dab3c99f/gtkhtml-sharp.dll gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gconf-sharp/2.6.0.0__35e10195dab3c99f/gconf-sharp.dll gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gconf-sharp-peditors/2.6.0.0__35e10195dab3c99f/gconf-sharp-peditors.dll gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/rsvg-sharp/2.6.0.0__35e10195dab3c99f/rsvg-sharp.dll rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/vte-sharp/2.6.0.0__35e10195dab3c99f/vte-sharp.dll vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtk-dotnet.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtk-dotnet/2.6.0.0__35e10195dab3c99f/gtk-dotnet.dll gtk-dotnet.dll )
